import React, { useEffect, useState } from "react";
import { Box, Modal, Typography, Grid, Button } from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import { useSelector } from "react-redux";
import { RootState } from "../../../redux/reducers";

type Props = {
	open: boolean;
	setViewModal: Function;
	handleView: (id: string | undefined) => void;
	id?: string | undefined;
};

const style = {
	position: "absolute",
	top: "50%",
	left: "50%",
	transform: "translate(-50%, -50%)",
	width: 500,
	boxShadow: "0px 4px 20px rgba(0, 0, 0, 0.15)",
	borderRadius: "10px",
	display: "flex",
	flexDirection: "column",
	padding: 0,
};

export default function UserViewModal({ open, setViewModal, id }: Props) {
	const { users } = useSelector(
		(state: RootState) => state.userReducer // Assuming users are stored in userReducer
	);
	const [selectedUser, setSelectedUser] = useState<any>(null);

	useEffect(() => {
		if (id) {
			const user = users.find((user) => user.id === id);
			setSelectedUser(user || null);
		}
	}, [id, users]);

	return (
		<Modal
			open={open}
			onClose={() => setViewModal(false)}
			aria-labelledby="modal-title"
			aria-describedby="modal-description"
		>
			<Box sx={style}>
				{/* Header Section */}
				<Box
					sx={{
						display: "flex",
						justifyContent: "space-between",
						alignItems: "center",
						backgroundColor: "#000000",
						color: "#D0E1E9",
						padding: "20px 24px",
						borderRadius: "10px 10px 0 0",
					}}
				>
					<Typography
						variant="h6"
						fontWeight={600}
						fontSize={"16px"}
						sx={{ flex: 1, textAlign: "center" }}
					>
						{selectedUser?.name || "User"}'s Details
					</Typography>
					<Box
						onClick={() => setViewModal(false)}
						sx={{
							cursor: "pointer",
							display: "flex",
							alignItems: "center",
							color: "#D0E1E9",
						}}
					>
						<CloseIcon />
					</Box>
				</Box>

				{/* Body Section */}
				<Box
					sx={{
						backgroundColor: "#b5c4cb",
						padding: "20px",
						borderRadius: "0 0 10px 10px", // Rounded bottom corners
					}}
				>
					{selectedUser ? (
						<Grid container spacing={2} sx={{ width: "80%" }}>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Name:</strong>{" "}
									<Typography variant="body2" color="#454545">
										{selectedUser.name}
									</Typography>
								</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Email:</strong>{" "}
									<Typography variant="body2" color="#454545">
										{selectedUser.email}
									</Typography>
								</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Phone:</strong>{" "}
									<Typography variant="body2" color="#454545">
										{selectedUser.phone ?? "N/A"}
									</Typography>
								</Typography>
							</Grid>
						</Grid>
					) : (
						<Typography align="center" color="#454545">
							No user found with this ID
						</Typography>
					)}

					{/* Close Button */}
					<Box
						sx={{
							display: "flex",
							justifyContent: "flex-end",
							mt: 3,
						}}
					>
						<Button
							onClick={() => setViewModal(false)}
							sx={{
								backgroundColor: "#000000",
								color: "#D0E1E9",
								borderRadius: "8px",
								fontSize: "16px",
								width: "117px",
								"&:hover": { backgroundColor: "#454545" },
							}}
						>
							Close
						</Button>
					</Box>
				</Box>
			</Box>
		</Modal>
	);
}
