import React, { useEffect, useState } from "react";
import { Box, Modal, Typography, Divider, Grid, Button } from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import { useSelector } from "react-redux";
import { RootState } from "../../../redux/reducers";

type Props = {
	open: boolean;
	setViewModal: Function;
	handleView: (id: number | undefined) => void;
	id?: number | undefined;
};

const style = {
position: "absolute",
	top: "50%",
	left: "50%",
	transform: "translate(-50%, -50%)",
	width: 500,
	bgcolor: "#000000",
	borderRadius: 2,
	boxShadow: "0px 4px 20px rgba(0, 0, 0, 0.15)",
	p: 0,
	display: "flex",
	flexDirection: "column",
	alignItems: "center",
	
};

export default function ManagerViewModal({ open, setViewModal, id }: Props) {
	const { managers } = useSelector(
		(state: RootState) => state.managerReducer
	);
	const [selectedManager, setSelectedManager] = useState<any>(null);

	useEffect(() => {
		if (id) {
			const manager = managers.find((manager) => manager.id === id);
			setSelectedManager(manager || null);
		}
	}, [id, managers]);

	return (
		<Modal
			open={open}
			aria-labelledby="modal-title"
			aria-describedby="modal-description"
		>
			<Box sx={style}>
				<Box
					sx={{
						display: "flex",
						justifyContent: "space-between",
						alignItems: "center",
						backgroundColor: "#000000",
						color: "#D0E1E9",
						padding: "20px 24px",
						borderRadius: "10px 10px 0 0",
					}}
				>
					<Typography
						id="modal-title"
						variant="h5"
						fontWeight="bold"
						sx={{ width: "100%" }}
					>
						<Box
							sx={{
								display: "flex",
								alignItems: "center",
								justifyContent: "space-between",
								width: "100%",
							}}
						>
							<Box
								sx={{
									flex: 1,
									textAlign: "center",
									color: "#D0E1E9",
								}}
							>
								{selectedManager?.name || "Manager"}'s Details
							</Box>
							<Box
								onClick={() => setViewModal(false)}
								sx={{
									cursor: "pointer",
									display: "flex",
									alignItems: "center",
									color: "#D0E1E9",
									marginLeft: "200px",
								}}
							>
								<CloseIcon />
							</Box>
						</Box>
					</Typography>
				</Box>

				{/* <Divider sx={{ width: "100%" }} /> */}
				<Box
					sx={{
						backgroundColor: "#b5c4cb",
						padding: "20px",
						borderRadius: "0 0 10px 10px", // Rounded bottom corners
					}}
				>
					{selectedManager ? (
						<Grid container spacing={2} sx={{ width: "80%" }}>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Name:</strong>
									<Typography variant="body2" color="#454545">
										{selectedManager.name}
									</Typography>
								</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Email:</strong>
									<Typography variant="body2" color="#454545">
										{selectedManager.email}
									</Typography>
								</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Phone:</strong>
									<Typography variant="body2" color="#454545">
										{selectedManager.phone}
									</Typography>
								</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Station Location:</strong>
									<Typography variant="body2" color="#454545">
										{selectedManager.chargingStation
											?.registeredAddress ||
											"Not Available"}
									</Typography>
								</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Station Name:</strong>
									<Typography variant="body2" color="#454545">
										{selectedManager.chargingStation
											?.name || "Not Available"}
									</Typography>
								</Typography>
							</Grid>
						</Grid>
					) : (
						<Typography align="center" color="#454545">
							No manager found with this ID
						</Typography>
					)}
					<Box
						sx={{
							display: "flex",
							justifyContent: "flex-end",
							mt: 3,
						}}
					>
						<Button
							onClick={() => setViewModal(false)}
							sx={{
								backgroundColor: "#000000",
								color: "#D0E1E9",
								borderRadius: "8px",
								fontSize: "16px",
								width: "117px",
								"&:hover": { backgroundColor: "#454545" },
							}}
						>
							Close
						</Button>
					</Box>
				</Box>
			</Box>
		</Modal>
	);
}
